@@ -92,6 +92,7 @@ class ConfigurationService(object):
             self._reload()
         except Exception, e:
             LOG.error('Reloading the configuration failed', exc_info=True)
+            return
 
         self.last_reload = time.time()
         zope.event.notify(ConfigurationChangedEvent(self.getConfiguration()))
@@ -132,8 +133,21 @@ class ConfigurationService(object):
         """ Return all configuration entries as dict """
         return self.opts.__dict__.copy() 
 
-    def __del__(self):
-        if self.notifier:
+    def getConfigurationForPrefix(self, prefix):
+        """ Return all configuration entries as dict for a given prefix"""
+        opts = self.getConfiguration().copy()
+        for opt in opts.keys():
+            opt_prefix, opt_key = opt.rsplit('.' , 1)
+            if opt_prefix != prefix:
+                del opts[opt]
+        return opts
+
+    def shutdown(self):
+        """ Explict shutdown of the notifier thread (basically required for
+            Zope integration).
+        """
+
+        if self.notifier is not None:
             self.notifier.stop()
 
 
